"""Dataview Editor package for managing CLICK PLC DataView files (.cdv)."""

from .dataview_editor_window import DataviewEditorWindow
from .shared_dataview_data import SharedDataviewData

__all__ = ["DataviewEditorWindow", "SharedDataviewData"]
